@@ -1,16 +1,10 @@
-# Search ranges
-ranges = [(1, 90), (91, 270)]
-
-# Dont use ichimoku or DPO (data leakage)
-indicators = ["pta.rsi", "pta.mom", "pta.macd"]
-
 # Series data
 tune_series = ['open', 'high', 'low', 'close', 'volume']
 
 # Add back in:  'offset'
 
 # Parameters to tune
-tune_params = ['width', 'fast', 'slow', 'signal', 'length', 'short', 'drift', 'max_lookback', 'min_lookback', 'initial',
+tune_params = ['width', 'fast', 'slow', 'signal', 'length', 'short', 'max_lookback', 'min_lookback', 'initial',
                'lower_length', 'upper_length', 'lookback', 'medium', 'slow_w', 'roc1', 'roc2', 'roc3', 'roc4',
                'sma1', 'sma2', 'sma3', 'sma4', 'scalar', 'width', 'long', 'atr_length', 'high_length',
                'low_length', 'kc_length', 'bb_length', 'mom_length', 'swma_length', 'rvi_length', 'period',
@@ -22,18 +16,3 @@ tune_params = ['width', 'fast', 'slow', 'signal', 'length', 'short', 'drift', 'm
                'minperiod', 'maxperiod', 'acceleration', 'accelerationlong', 'accelerationshort', 'signalperiod',
                'slowperiod', 'signalperiod', 'fastperiod', 'fastk_period', 'slowk_period', 'slowd_period',
                'fastd_period']
-
-# tune_params = ['th']
-
-# Index of column to maximize if indicator returns multiple
-tune_column = {
-    "pta.aobv": 5,
-    "pta.thermo": 2,
-    "pta.vp": 5,
-    "pta.bbands": 3,
-    "pta.aroon": 2,
-    "pta.macd": 2,
-}
-
-
-
